@@ -212,8 +212,8 @@ class ColorMapPanel(wx.Panel):
         if (hi-lo)<2:
             hi = min(hi, conf.cmap_range)
             lo = max(lo, 0)
-        self.cmap_lo.SetValue(lo)
-        self.cmap_hi.SetValue(hi)
+        self.cmap_lo.SetValue(float(lo))
+        self.cmap_hi.SetValue(float(hi))
         conf.cmap_lo[col] = lo
         conf.cmap_hi[col] = hi
         imin = float(self.imin_val.GetValue())
