@@ -10,7 +10,7 @@ from datetime import datetime
 import wx
 
 from numpy import nonzero, where
-import matplotlib
+import matplotlib as mpl
 from matplotlib import dates
 from matplotlib.figure import Figure
 from matplotlib.ticker import FuncFormatter
@@ -123,10 +123,12 @@ class PlotPanel(BasePanel):
         basic plot method, adding to an existing display
 
         """
+
         self.cursor_mode = 'zoom'
         conf = self.conf
         conf.plot_type = 'lineplot'
         axes = self.axes
+
         if theme is not None:
             conf.set_theme(theme=theme)
         if side == 'right':
@@ -164,13 +166,13 @@ class PlotPanel(BasePanel):
         conf.viewpad = ifnot_none(viewpad, conf.viewpad)
 
         if xlabel is not None:
-            self.set_xlabel(xlabel, delay_draw=delay_draw)
+            self.set_xlabel(xlabel, delay_draw=True)
         if ylabel is not None:
-            self.set_ylabel(ylabel, delay_draw=delay_draw)
+            self.set_ylabel(ylabel, delay_draw=True)
         if y2label is not None:
-            self.set_y2label(y2label, delay_draw=delay_draw)
+            self.set_y2label(y2label, delay_draw=True)
         if title  is not None:
-            self.set_title(title, delay_draw=delay_draw)
+            self.set_title(title, delay_draw=True)
         if show_legend is not None:
             conf.set_legend_location(legend_loc, legend_on)
             conf.show_legend = show_legend
@@ -179,7 +181,6 @@ class PlotPanel(BasePanel):
 
         # set data range for this trace
         # datarange = [min(xdata), max(xdata), min(ydata), max(ydata)]
-
         if axes not in conf.user_limits:
             conf.user_limits[axes] = [None, None, None, None]
 
@@ -201,13 +202,10 @@ class PlotPanel(BasePanel):
 
         conf.gridcolor = ifnot_none(gridcolor, conf.gridcolor)
         conf.set_gridcolor(conf.gridcolor)
-
         conf.facecolor = ifnot_none(bgcolor, conf.facecolor)
         conf.set_facecolor(conf.facecolor)
-
         conf.textcolor = ifnot_none(textcolor, conf.textcolor)
-        conf.set_textcolor(conf.textcolor)
-
+        conf.set_textcolor(conf.textcolor, delay_draw=True)
         if framecolor is not None:
             conf.set_framecolor(framecolor)
 
@@ -232,6 +230,7 @@ class PlotPanel(BasePanel):
             fkws = dict(step=None, zorder=zorder, color=color)
             if drawstyle != 'default':
                 fkws['step'] = drawstyle
+            _lines = axes.plot(xdata, ydata, drawstyle=drawstyle, zorder=zorder, color=color)
             if dy is None:
                 _fill = axes.fill_between(xdata, ydata, y2=0, **fkws)
             else:
@@ -243,6 +242,7 @@ class PlotPanel(BasePanel):
                 _lines = [ebar.lines[0], ebar.lines[2]]
             else:
                 _lines = axes.plot(xdata, ydata, drawstyle=drawstyle, zorder=zorder)
+
         conf.traces[conf.ntrace].fill = fill
 
         if axes not in conf.data_save:
@@ -251,9 +251,13 @@ class PlotPanel(BasePanel):
 
         if conf.show_grid and axes == self.axes:
             # I'm sure there's a better way...
-            for i in axes.get_xgridlines() + axes.get_ygridlines():
-                i.set_color(conf.gridcolor)
-                i.set_zorder(-100)
+            # conf.set_gridcolor(conf.gridcolor)
+            mpl.rcParams['grid.color'] = conf.gridcolor
+
+            # grid_color = mpl.rcParams["grid.color"]
+            # for i in axes.get_xgridlines() + axes.get_ygridlines():
+            #     i.set_color(conf.gridcolor)
+            #     i.set_zorder(-100)
             axes.grid(True)
         else:
             axes.grid(False)
@@ -261,7 +265,7 @@ class PlotPanel(BasePanel):
         if (self.conf.xscale == 'log' or self.conf.yscale == 'log'):
             self.set_logscale(xscale=self.conf.xscale,
                               yscale=self.conf.yscale,
-                              delay_draw=delay_draw)
+                              delay_draw=True)
 
         if label is None:
             label = 'trace %i' % (conf.ntrace+1)
@@ -293,13 +297,11 @@ class PlotPanel(BasePanel):
         if refresh:
             conf.refresh_trace(conf.ntrace)
             needs_relabel = True
+        if conf.show_legend:
+            conf.draw_legend(delay_draw=True)
 
-        if conf.show_legend and not delay_draw:
-            conf.draw_legend()
-
-        if needs_relabel and not delay_draw:
-            conf.relabel()
-
+        if needs_relabel:
+            conf.relabel(delay_draw=True)
 
         # axes style ('box' or 'open')
         conf.axes_style = 'box'
@@ -307,15 +309,16 @@ class PlotPanel(BasePanel):
             conf.axes_style = 'open'
         if axes_style in ('open', 'box', 'bottom'):
             conf.axes_style = axes_style
+
         conf.set_axes_style(delay_draw=delay_draw)
         if not delay_draw:
             self.draw()
-            self.canvas.Refresh()
+            # self.canvas.Refresh()
         conf.ntrace = conf.ntrace + 1
         return _lines
 
     def plot_many(self, datalist, side='left', title=None,
-                  xlabel=None, ylabel=None, **kws):
+                  xlabel=None, ylabel=None, show_legend=False, zoom_limits=None, **kws):
         """
         plot many traces at once, taking a list of (x, y) pairs
         """
@@ -332,9 +335,10 @@ class PlotPanel(BasePanel):
                 ydata = tdat[1]
             return (xdata, ydata, out)
 
+
         conf = self.conf
         opts = dict(side=side, title=title, xlabel=xlabel, ylabel=ylabel,
-                    delay_draw=True)
+                    delay_draw=True, show_legend=False)
         opts.update(kws)
         x0, y0, opts = unpack_tracedata(datalist[0], **opts)
 
@@ -346,21 +350,41 @@ class PlotPanel(BasePanel):
             for i in range(nplot_traces, nplot_request+5):
                 conf.init_trace(i,  linecolors[i%ncols], 'dashed')
 
-
         self.plot(x0, y0, **opts)
-
-
         for dat in datalist[1:]:
             x, y, opts = unpack_tracedata(dat, delay_draw=True)
             self.oplot(x, y, **opts)
 
         self.reset_formats()
-
-        if conf.show_legend:
-            conf.draw_legend()
-        conf.relabel()
+        self.set_zoomlimits(zoom_limits)
+        self.conf.show_legend = show_legend
+        if show_legend:
+            conf.draw_legend(delay_draw=True)
+        conf.relabel(delay_draw=True)
         self.draw()
-        self.canvas.Refresh()
+        # self.canvas.Refresh()
+
+
+    def get_zoomlimits(self):
+        return self.axes, self.get_viewlimits(), self.conf.zoom_lims
+
+    def set_zoomlimits(self, limits):
+        """set zoom limits returned from get_zoomlimits()"""
+        if limits is None:
+            # print("panel.set_zoom none")
+            return False
+        ax, vlims, zoom_lims = limits
+        if ax == self.axes:
+            try:
+                ax.set_xlim((vlims[0], vlims[1]), emit=True)
+                ax.set_ylim((vlims[2], vlims[3]), emit=True)
+                if len(zoom_lims) > 0:
+                    self.conf.zoom_lims = zoom_lims
+            except:
+                # print("panel.set_zoom error")
+                return False
+        return True
+
 
     def add_text(self, text, x, y, side='left', size=None,
                  rotation=None, ha='left', va='center',
